Index: util.lisp
===================================================================
--- util.lisp   (revision 4016)
+++ util.lisp   (working copy)
@@ -121,9 +121,16 @@
               (random base *the-random-state*)))))
 
 (defun reset-session-secret ()
-  "Sets *SESSION-SECRET* to a new random value. All old sessions will
-cease to be valid."
-  (setq *session-secret* (create-random-string 10 36)))
+  "Sets *SESSION-SECRET* to a new value based on *SESSION-SECRETIZER*
+and a [pseudo] random string. All old sessions will cease to be valid."
+  (when (not *session-secretizer*)
+    (warn "It is recommended to set *SESSION-SECRETIZER* to some secret 
+value (pass-phrase) in order to make session identifiers unguessable."))
+  ;; even when *session-secretizer* is specified, we add a random string
+  ;; so that resulting *session-secret* is always unique.
+  (setq *session-secret* (concatenate 'string
+                                      *session-secretizer*
+                                      (create-random-string 10 36))))
 
 (defun reason-phrase (return-code)
   "Returns a reason phrase for the HTTP return code RETURN-CODE
Index: packages.lisp
===================================================================
--- packages.lisp   (revision 4016)
+++ packages.lisp   (working copy)
@@ -72,6 +72,7 @@
            "*SHOW-LISP-BACKTRACES-P*"
            "*SHOW-LISP-ERRORS-P*"
            "*TMP-DIRECTORY*"
+           "*SESSION-SECRETIZER*"
            "*USE-REMOTE-ADDR-FOR-SESSIONS*"
            "*USE-USER-AGENT-FOR-SESSIONS*"
            "+HTTP-ACCEPTED+"
Index: doc/index.xml
===================================================================
--- doc/index.xml   (revision 4016)
+++ doc/index.xml   (working copy)
@@ -1830,6 +1830,21 @@
         are <a href="#session-gc">automatically removed</a>.
       </p>
 
+      <clix:special-variable name="*session-secretizer*">
+        <clix:description>
+          If not NIL, it will be encoded into session identifier. Expected to be set to some 
+          secret value (pass-phrase) in order to make session identifiers unguessable by 
+          malicious users.  
+          <p>
+            Other web servers probably can generate such a secret value
+            automatically using OS API (as /dev/random on Linux or CryptoAPI 
+            on Windows), but hunchentoot has not yet implemented a portable 
+            way to generate unpredictable secrets and therefore you need to 
+            set this variable if you want sessions to be more secure.
+          </p>
+        </clix:description>
+      </clix:special-variable>
+
       <clix:special-variable name="*session*">
         <clix:description>
           Holds the current <code>SESSION</code> object (if any) or <code>NIL</code>.
Index: specials.lisp
===================================================================
--- specials.lisp   (revision 4016)
+++ specials.lisp   (working copy)
@@ -139,6 +139,11 @@
 (defvar-unbound *session-secret*
   "A random value that's used to encode the public session data.")
 
+(defvar *session-secretizer* nil
+  "If not NIL, it will be encoded into session identifier. Expected to
+be set to some secret value (pass-phrase) in order to make session 
+identifiers unguessable by malicious users.")
+
 (defvar-unbound *hunchentoot-stream*
   "The stream representing the socket Hunchentoot is listening on.")
 
